##############################
##Investor EDB
##############################

require(foreign)
require(stargazer)
require(boot)
require(coin)


setwd("C:/Users/RD/Desktop/Replication/")
cledata <- read.csv(file = "Investor.Data.12018.csv", header = TRUE)

###################
### KEY STATS #####
###################

#7 extremely likely, 
#6 moderately likely, 
#5 slightly likely, 
#4 neither likely nor unlikely, 
#3 slightly unlikely, 
#2 moderately unlikely, 
#1 extremely unlikely.


#For questions about codings and Likert scales, see the appendix


#########################
### Panel Description ###
#########################

#Years of Experience
summary(cledata$YearsofExperience)

#Title (CEO+Partner+VP+MD+SD+P = 73)
summary(cledata$Title)

#Age
2017-mean(cledata$Birth)
2017-range(cledata$Birth)

#Gender
summary(cledata$Gender)/150

#Industry
summary(cledata$Industry)/150

#Strategy
summary(cledata$Strategy)/150

#########################
# Interesting Questions #
#########################

#Use EDB
summary(cledata$Exp1UseEDB)/51

#EDB Knowledge #Roughly 40% used it; 60% did not
summary(cledata$EDBKnowledge)/150 


#Info checks (EDB is least memorable)
summary(cledata$Check.EDB)
summary(cledata$Check.EDB=="130") #29
summary(cledata$Check.EDB=="30") #30 (Total 59%)
summary(cledata$CheckInfl)/150 #64%
summary(cledata$CheckPCGDP)/150 #79%
summary(cledata$CheckGDP)/150 #62%
summary(cledata$CheckUnemp)/150 #67%

#Check India/Kenya
summary(cledata$IndiaEDB) #Median -- People think India is 101
summary(cledata$KenyaEDB) #Median -- People think Kenya is 132

#Check Banks
summary(cledata$RankingInstitution) #88% for WB
summary(cledata$RankingInstitutionCountry) #82% for WB

#Ranking Organization
summary(cledata$RankingOrganization)/150 #WB is 65; Economist is 50; Brookings 20; Heritage 14

###################
### Experiment 1 ##
###################

#subset
control1 <- subset(cledata, cledata$Exp1Code=="1") ## no EDB
treatment1 <- subset(cledata, cledata$Exp1Code=="2") ## EDB 30
treatment2 <- subset(cledata, cledata$Exp1Code=="3") ## EDB 130


#propensity to invest
mean(control1$Exp1Q1) 
mean(treatment1$Exp1Q1)
mean(treatment2$Exp1Q1)

#risk premium
mean(control1$Exp1Q2) #control = 
mean(treatment1$Exp1Q2) #treatment 1 =
mean(treatment2$Exp1Q2) #treatment 2 = 

###################
###### TEST 1 #####
###################

## Treatment 1 vs. Treatment 2 ##
## 30          vs.    130      ##


#merge
Test1<- rbind(treatment1, treatment2)


#dummy variable
for (i in 1:nrow(Test1)){
  if (Test1$Exp1Code[i] == "3"){Test1$Exp1Code[i] <- 0}
  else {Test1$Exp1Code[i] <- 1}
}

########
## Q1 ##   #### This is Table 6, Row 1 ####
########

#Investment Propensity

#Regression
Test1investmentpropensity <- lm(Exp1Q1~Exp1Code, data=Test1)
summary(Test1investmentpropensity)

Test1investmentpropensityControls <- lm(Exp1Q1~Exp1Code+Exp1Q2.6+Industry+Strategy+Title+YearsofExperience, data=Test1)
summary(Test1investmentpropensityControls)

#wilcox
wilcox.test(Test1$Exp1Q1~Test1$Exp1Code, mu=0, alt="two.sided", conf.int=T, conf.level=.95, paired=F)


########
## Q2 ##
########

#Return 

#regression
Test1Return<- lm(Exp1Q2~Exp1Code, data=Test1)
summary(Test1Return)

#wilcox
wilcox.test(Test1$Exp1Q1~Test1$Exp1Code, mu=0, alt="two.sided", conf.int=T, conf.level=.95, paired=F)

########
## Q3 ##
########

#regression

Test1govcomp<- lm(Exp1Q3.1~Exp1Code, data=Test1)
summary(Test1govcomp)

Test1CorruptionEffect <- lm(Exp1Q3.2~Exp1Code, data=Test1)
summary(Test1CorruptionEffect)

Test1AttractInvestment <- lm(Exp1Q3.3~Exp1Code, data=Test1)
summary(Test1AttractInvestment)

Test1TreatFairly <- lm(Exp1Q3.4~Exp1Code, data=Test1)
summary(Test1TreatFairly)

########
## Q4 ##
########

Test1GDPImp <- lm(Exp1Q4.1~Exp1Code, data=Test1)
summary(Test1GDPImp)

Test1InflationImp <- lm(Exp1Q4.2~Exp1Code, data=Test1)
summary(Test1InflationImp)

Test1UnemploymentImp <- lm(Exp1Q4.3~Exp1Code, data=Test1)
summary(Test1UnemploymentImp)

Test1PCGDPImp<- lm(Exp1Q4.4~Exp1Code, data=Test1)
summary(Test1PCGDPImp)

Test1EDB<- lm(Exp1Q4.5~Exp1Code, data=Test1)
summary(Test1EDB)


########
## Q5 ##
########

Test1StartingBusiness <- lm(Exp1Q5.1~Exp1Code, data=Test1)
summary(Test1StartingBusiness)

Test1TransferProp <- lm(Exp1Q5.2~Exp1Code, data=Test1)
summary(Test1TransferProp)

Test1ContractEnf <- lm(Exp1Q5.3~Exp1Code, data=Test1)
summary(Test1ContractEnf)

Test1BusinessCost <- lm(Exp1Q5.4~Exp1Code, data=Test1)
summary(Test1BusinessCost)

Test1GovComp <- lm(Exp1Q5.5~Exp1Code, data=Test1)
summary(Test1GovComp)

Test1Discrim <- lm(Exp1Q5.6~Exp1Code, data=Test1)
summary(Test1Discrim)

###################
###### TEST 2 ##### 
###################

## Control 1 vs. Treatment 1 ##
##  No rank  vs.   30        ##


#merge
Test2<- rbind(control1, treatment1)


#dummy variable where 0 is control and 1 is high rank
for (i in 1:nrow(Test2)){
  if (Test2$Exp1Code[i] == "1"){Test2$Exp1Code[i] <- 0}
  else {Test2$Exp1Code[i] <- 1}
}

########
## Q1 ##  #### This is Table 6, Row 3 ####
########

#Investment Propensity

#regression
Test2investmentpropensity <- lm(Exp1Q1~Exp1Code, data=Test2)
summary(Test2investmentpropensity)

Test2investmentpropensityControls <- lm(Exp1Q1~Exp1Code+Exp1Q2.6+Industry+Strategy+Title+YearsofExperience, data=Test2)
summary(Test2investmentpropensityControls)

#wilcox
wilcox.test(Test2$Exp1Q1~Test2$Exp1Code, mu=0, alt="two.sided", conf.int=T, conf.level=.95, paired=F)

########
## Q2 ##
########

#Return 

#regression
Test2Return<- lm(Exp1Q2~Exp1Code, data=Test2)
summary(Test2Return)

#wilcox
wilcox.test(Test2$Exp1Q1~Test2$Exp1Code, mu=0, alt="two.sided", conf.int=T, conf.level=.95, paired=F)



########
## Q3 ##
########

#regression

Test2govcomp<- lm(Exp1Q3.1~Exp1Code, data=Test2)
summary(Test2govcomp)

Test2CorruptionEffect <- lm(Exp1Q3.2~Exp1Code, data=Test2)
summary(Test2CorruptionEffect)


Test2AttractInvestment <- lm(Exp1Q3.3~Exp1Code, data=Test2)
summary(Test2AttractInvestment)

mean(Test2$Exp1Q3.3[Test2$Exp1Code==1])

Test2TreatFairly <- lm(Exp1Q3.4~Exp1Code, data=Test2)
summary(Test2TreatFairly)

########
## Q4 ##
########

Test2GDPImp <- lm(Exp1Q4.1~Exp1Code, data=Test2)
summary(Test2GDPImp)

Test2InflationImp <- lm(Exp1Q4.2~Exp1Code, data=Test2)
summary(Test2InflationImp)

Test2UnemploymentImp <- lm(Exp1Q4.3~Exp1Code, data=Test2)
summary(Test2UnemploymentImp)

Test2PCGDPImp<- lm(Exp1Q4.4~Exp1Code, data=Test2)
summary(Test2PCGDPImp)


########
## Q5 ##
########

Test2StartingBusiness <- lm(Exp1Q5.1~Exp1Code, data=Test2)
summary(Test2StartingBusiness)

Test2TransferProp <- lm(Exp1Q5.2~Exp1Code, data=Test2)
summary(Test2TransferProp)

Test2ContractEnf <- lm(Exp1Q5.3~Exp1Code, data=Test2)
summary(Test2ContractEnf)

Test2BusinessCost <- lm(Exp1Q5.4~Exp1Code, data=Test2)
summary(Test2BusinessCost)

Test2GovComp <- lm(Exp1Q5.5~Exp1Code, data=Test2)
summary(Test2GovComp)

Test2Discrim <- lm(Exp1Q5.6~Exp1Code, data=Test2)
summary(Test2Discrim)


###################
###### TEST 3 #####  #### This is Table 6, Row 2 ####
###################

## Treatment 2 vs. Control 1 ##
##  130        vs. No Rank   ##


#merge
Test3<- rbind(control1, treatment2)


#dummy variable where 0 is Treatment 2 and 1 is Control 1
for (i in 1:nrow(Test3)){
  if (Test3$Exp1Code[i] == "1"){Test3$Exp1Code[i] <- 1}
  else {Test3$Exp1Code[i] <- 0}
}


########
## Q1 ##
########

#regression
Test3investmentpropensity <- lm(Exp1Q1~Exp1Code, data=Test3)
summary(Test3investmentpropensity)

Test3investmentpropensityControls <- lm(Exp1Q1~Exp1Code+Exp1Q2.6+Industry+Strategy+Title+YearsofExperience, data=Test3)
summary(Test3investmentpropensityControls)


#wilcox
wilcox.test(Test3$Exp1Q1~Test3$Exp1Code, mu=0, alt="two.sided", conf.int=T, conf.level=.95, paired=F)


########
## Q2 ##
########

#Return 

#regression
Test3Return<- lm(Exp1Q2~Exp1Code, data=Test3)
summary(Test3Return)

#wilcox
wilcox.test(Test3$Exp1Q1~Test3$Exp1Code, mu=0, alt="two.sided", conf.int=T, conf.level=.95, paired=F)

########
## Q3 ##
########

#regression

Test3govcomp<- lm(Exp1Q3.1~Exp1Code, data=Test3)
summary(Test3govcomp)

Test3CorruptionEffect <- lm(Exp1Q3.2~Exp1Code, data=Test3)
summary(Test3CorruptionEffect)

Test3AttractInvestment <- lm(Exp1Q3.3~Exp1Code, data=Test3)
summary(Test3AttractInvestment)

Test3TreatFairly <- lm(Exp1Q3.4~Exp1Code, data=Test3)
summary(Test3TreatFairly)

########
## Q4 ##
########

Test3GDPImp <- lm(Exp1Q4.1~Exp1Code, data=Test3)
summary(Test3GDPImp)

Test3InflationImp <- lm(Exp1Q4.2~Exp1Code, data=Test3)
summary(Test3InflationImp)

Test3UnemploymentImp <- lm(Exp1Q4.3~Exp1Code, data=Test3)
summary(Test3UnemploymentImp)

Test3PCGDPImp<- lm(Exp1Q4.4~Exp1Code, data=Test3)
summary(Test3PCGDPImp)


########
## Q5 ##
########

Test3StartingBusiness <- lm(Exp1Q5.1~Exp1Code, data=Test3)
summary(Test3StartingBusiness)

Test3TransferProp <- lm(Exp1Q5.2~Exp1Code, data=Test3)
summary(Test3TransferProp)

Test3ContractEnf <- lm(Exp1Q5.3~Exp1Code, data=Test3)
summary(Test3ContractEnf)

Test3BusinessCost <- lm(Exp1Q5.4~Exp1Code, data=Test3)
summary(Test3BusinessCost)

Test3GovComp <- lm(Exp1Q5.5~Exp1Code, data=Test3)
summary(Test3GovComp)

Test3Discrim <- lm(Exp1Q5.6~Exp1Code, data=Test3)
summary(Test3Discrim)

######################
## Bootstrap Tests  ## #### This is Table 6, All Bootstrapped T Tests ####
######################

##T.Test Function
t.test2 <- function(m1,m2,s1,s2,n1,n2,m0=0,equal.variance=FALSE)
{
  if( equal.variance==FALSE ) 
  {
    se <- sqrt( (s1^2/n1) + (s2^2/n2) )
    # welch-satterthwaite df
    df <- ( (s1^2/n1 + s2^2/n2)^2 )/( (s1^2/n1)^2/(n1-1) + (s2^2/n2)^2/(n2-1) )
  } else
  {
    # pooled standard deviation, scaled by the sample sizes
    se <- sqrt( (1/n1 + 1/n2) * ((n1-1)*s1^2 + (n2-1)*s2^2)/(n1+n2-2) ) 
    df <- n1+n2-2
  }      
  t <- (m1-m2-m0)/se 
  dat <- c(m1-m2, se, t, 2*pt(-abs(t),df))    
  names(dat) <- c("Difference of means", "Std Error", "t", "p-value")
  return(dat) 
}

values[i] <- t.test2( mean(t5), mean(t3), sd(t5), sd(t3), length(t5), length(t3))

### Bootstrap Difference in Means: Test 1

set.seed(02138)
nreps <- 10000
t3 <- Test1$Exp1Q1[Test1$Exp1Code==0]
t5 <- Test1$Exp1Q1[Test1$Exp1Code==1]
t3holder <- rep(NA,nreps)
t5holder <- rep(NA,nreps)
values <- data.frame (diffofmeans = numeric(0), "stderror" = numeric(0), tscore = numeric(0), pvalue = numeric(0))

for(i in 1:nreps){
  t5holder <-sample(t5, length(t5), replace = TRUE)
  t3holder <- sample(t3, length(t3), replace = TRUE)
  values[i,] <- t.test2( mean(t5holder), mean(t3holder), sd(t5holder), sd(t3holder), length(t5holder), length(t3holder))
}

tscore <- (mean(values$diffofmeans))/((mean(values$stderror)))
2*pt(-abs(tscore),10000)

mean(values$diffofmeans)
mean(values$stderror)


### Bootstrap Difference in Means: Test 2

set.seed(02138)
nreps <- 10000
t3 <- Test2$Exp1Q1[Test2$Exp1Code==0]
t5 <- Test2$Exp1Q1[Test2$Exp1Code==1]
t3holder <- rep(NA,nreps)
t5holder <- rep(NA,nreps)
values <- data.frame (diffofmeans = numeric(0), "stderror" = numeric(0), tscore = numeric(0), pvalue = numeric(0))

for(i in 1:nreps){
  t5holder <-sample(t5, length(t5), replace = TRUE)
  t3holder <- sample(t3, length(t3), replace = TRUE)
  values[i,] <- t.test2( mean(t5holder), mean(t3holder), sd(t5holder), sd(t3holder), length(t5holder), length(t3holder))
}

tscore <- (mean(values$diffofmeans))/((mean(values$stderror)))
2*pt(-abs(tscore),10000)

mean(values$diffofmeans)
mean(values$stderror)

### Bootstrap Difference in Means: Test 3

set.seed(02138)
nreps <- 10000
c1 <- Test3$Exp1Q1[Test3$Exp1Code==0]
c2 <- Test3$Exp1Q1[Test3$Exp1Code==1]
c1holder <- rep(NA,nreps)
c2holder <- rep(NA,nreps)
values3 <- data.frame (diffofmeans = numeric(0), "stderror" = numeric(0), tscore = numeric(0), pvalue = numeric(0))

for(i in 1:nreps){
  c1holder <-sample(c1, length(c1), replace = TRUE)
  c2holder <- sample(c2, length(c2), replace = TRUE)
  values3[i,] <- t.test2(mean(c2holder), mean(c1holder), sd(c2holder), sd(c1holder), length(c2holder), length(c1holder))
}

tscore3 <- (mean(values3$diffofmeans))/((mean(values3$stderror)))
2*pt(-abs(tscore3),10000)

mean(values3$diffofmeans)
mean(values3$stderror)



