** Replication file for "The Power of Ranking: The Ease of Doing Business Indicator and Global Regulatory Behavior"
** Requirement: outreg2 - install via ssc install outreg2

** Load data
use "WorldBankAugust2018.dta"

** Format the panel data
xtset ccode year

* For reforms, if reform is missing, should be a 0 (no reforms) between 2006 and 2015
replace sb_reform=0 if sb_reform==. & year>2006 & year<2015
replace cp_reform=0 if cp_reform==. & year>2006 & year<2015
replace el_reform=0 if el_reform==. & year>2006 & year<2015
replace rp_reform=0 if rp_reform==. & year>2006 & year<2015
replace cred_reform=0 if cred_reform==. & year>2006 & year<2015
replace pmi_reform=0 if pmi_reform==. & year>2006 & year<2015
replace tx_reform=0 if tx_reform==. & year>2006 & year <2015
replace trade_reform=0 if trade_reform==. & year>2006 & year<2015
replace con_reform=0 if con_reform==. & year>2006 & year< 2015
replace insolv_reform=0 if insolv_reform==. & year>2006 & year<2015

* Calculate the total number of reforms
gen tot_reforms= sb_reform + cp_reform + el_reform + rp_reform + cred_reform + pmi_reform + tx_reform + trade_reform + con_reform + insolv_reform
summ tot_reforms

* Change in ranks from year-to-year
gen leap= p_edb_rank_lag-p_edb_rank
summ leap

* Summarize statistics by whether country has a reform bureau

* Total number of reforms
summ tot_reforms if has_bureau == 1 & year > 2006 & year < 2015
summ tot_reforms if has_bureau == 0 & year > 2006 & year < 2015
* Hypothesis test
reg tot_reforms has_bureau, cluster(ccode)

* Rank changes
summ leap if has_bureau==0 & year>2007
summ leap if has_bureau==1 & year>2007

* Average rank in start year/end year by states that have bureaus/don't have bureaus 
summ p_edb_rank if has_bureau==1 & year==2007
summ p_edb_rank if has_bureau==1 & year==2014
summ p_edb_rank if has_bureau==0 & year==2007
summ p_edb_rank if has_bureau==0 & year==2014

* Is the state ranked by the EDB in the year
gen edb_rank_notmissing = !missing(p_edb_rank)

* First year of EDB rank
bysort ccode edb_rank_notmissing (year): egen firstyear = min(year)
bysort ccode edb_rank_notmissing (year): egen lastyear = max(year)

* Average among countries ranked in both years 2007 and 2014 (exclude Slovakia which was ranked in 2005 but not in 2007)
summ p_edb_rank if has_bureau==1 & year==2007 & edb_rank_notmissing == 1 &firstyear <= 2007 & lastyear == 2014 & country_me != "Slovakia"
summ p_edb_rank if has_bureau==1 & year==2014 & edb_rank_notmissing == 1 &firstyear <= 2007 & lastyear == 2014 & country_me != "Slovakia"

summ p_edb_rank if has_bureau==0 & year==2007 & edb_rank_notmissing == 1 &firstyear <= 2007 & lastyear == 2014 & country_me != "Slovakia"
summ p_edb_rank if has_bureau==0 & year==2014 & edb_rank_notmissing == 1 &firstyear <= 2007 & lastyear == 2014 & country_me != "Slovakia"

** Replicate: Table 3

xtset ccode year
xtreg p_edb_rank L.p_edb_rank L.has_bureau i.year if year >2007, robust cluster(ccode)
outreg2 using EDB_Table3.xls, ctitle(Model 1) label stats(coef se) paren(se) e(N r2) replace  
xtreg p_edb_rank L.p_edb_rank L.tot_reforms i.year, robust cluster(ccode)
outreg2 using EDB_Table3.xls, append ctitle(Model 2) label stats(coef se) paren(se) e(N r2) 
xtreg p_edb_rank L.p_edb_rank L.tot_reforms i.year if L.has_bureau==0 , robust cluster(ccode)
outreg2 using EDB_Table3.xls, append ctitle(Model 3) label stats(coef se) paren(se) e(N r2) 
xtreg p_edb_rank L.p_edb_rank L.tot_reforms i.year if L.has_bureau==1 , robust cluster(ccode)
outreg2 using EDB_Table3.xls, append ctitle(Model 4) label stats(coef se) paren(se) e(N r2)  

gen interaction = has_bureau*tot_reforms

xtreg p_edb_rank L.p_edb_rank L.tot_reforms L.interaction L.has_bureau i.year , robust cluster(ccode)
outreg2 using EDB_Table3.xls, append ctitle(Model 5) label stats(coef se) paren(se) e(N r2)  


** Replicate: Table 5
xtset ccode year
xtreg sb_capital_ln L.sb_capital_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, replace ctitle(Model 1) label stats(coef se) paren(se) e(N r2) 
xtreg sb_cost_ln L.sb_cost_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 2) label stats(coef se) paren(se) e(N r2)
xtreg sb_proced_ln L.sb_proced_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 3) label stats(coef se) paren(se) e(N r2) 
xtreg sb_days_ln L.sb_days_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 4) label stats(coef se) paren(se) e(N r2)
xtreg sb_capital_ln L.sb_capital_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln year  i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 5) label stats(coef se) paren(se) e(N r2)   
xtreg sb_cost_ln L.sb_cost_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln year  i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 6) label stats(coef se) paren(se) e(N r2)  
xtreg sb_proced_ln L.sb_proced_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln year  i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 7) label stats(coef se) paren(se) e(N r2) 
xtreg sb_days_ln L.sb_days_ln L.ranked L.gdp_ln L.gdpgrowth L.polity  L.loan_ln year  i.ccode if in_2004==1, cluster (ccode) robust
outreg2 using EDB_Table5.xls, append ctitle(Model 8) label stats(coef se) paren(se) e(N r2)  

